@@ -163,6 +163,17 @@ class Script(Gecko.Script):
         - event: the Event
         """
 
+        # Much of the Gecko code is designed to handle Gecko's broken
+        # caret navigation. This is not needed in -- and can sometimes
+        # interfere with our presentation of -- a simple message being
+        # composed by the user. Surely we can count on Thunderbird to
+        # handle navigation in that case.
+        #
+        if self.isEditableMessage(event.source) \
+           or self.isNonHTMLEntry(event.source):
+            self.setCaretContext(event.source, event.detail1)
+            return default.Script.onCaretMoved(self, event)
+
         # Page_Up/Page_Down are not used by Orca. However, users report
         # using these keys in Thunderbird without success. The default
         # script is sometimes rejecting the resulting caret-moved events
@@ -336,7 +347,16 @@ class Script(Gecko.Script):
                     pass
 
         if not consume:
-            Gecko.Script.onFocus(self, event)
+            # Much of the Gecko code is designed to handle Gecko's broken
+            # caret navigation. This is not needed in -- and can sometimes
+            # interfere with our presentation of -- a simple message being
+            # composed by the user. Surely we can count on Thunderbird to
+            # handle navigation in that case.
+            #
+            if self.isEditableMessage(event.source):
+                default.Script.onFocus(self, event)
+            else:
+                Gecko.Script.onFocus(self, event)
 
     def locusOfFocusChanged(self, event, oldLocusOfFocus, newLocusOfFocus):
         """Called when the visual object with focus changes.
@@ -353,12 +373,10 @@ class Script(Gecko.Script):
         # number as the previously deleted message).
         # See bug #536451 for more details.
         #
-        rolesList = [pyatspi.ROLE_TABLE_CELL, \
-                     pyatspi.ROLE_TREE_TABLE, \
-                     pyatspi.ROLE_SCROLL_PANE, \
-                     pyatspi.ROLE_SCROLL_PANE, \
-                     pyatspi.ROLE_FRAME, \
-                     pyatspi.ROLE_APPLICATION]
+        rolesList = [pyatspi.ROLE_TABLE_CELL,
+                     pyatspi.ROLE_TREE_TABLE,
+                     pyatspi.ROLE_SCROLL_PANE,
+                     pyatspi.ROLE_SCROLL_PANE]
         if self.isDesiredFocusedItem(event.source, rolesList):
             if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent):
                 string = orca_state.lastNonModifierKeyEvent.event_string
@@ -579,11 +597,30 @@ class Script(Gecko.Script):
             self.sayAll(None)
         self._messageLoaded = False
 
+    def getBottomOfFile(self):
+        """Returns the object and last caret offset at the bottom of the
+        document frame. Overridden here to handle editable messages.
+        """
+
+        # Pylint thinks that obj is an instance of a list. It most
+        # certainly is not. Silly pylint.
+        #
+        # pylint: disable-msg=E1103
+        #
+        [obj, offset] = Gecko.Script.getBottomOfFile(self)
+        if obj and obj.getState().contains(pyatspi.STATE_EDITABLE):
+            offset += 1
+
+        return [obj, offset]
+
     def getDocumentFrame(self):
         """Returns the document frame that holds the content being shown.
         Overridden here because multiple open messages are not arranged
         in tabs like they are in Firefox."""
 
+        if self.inFindToolbar():
+            return Gecko.Script.getDocumentFrame(self)
+
         obj = orca_state.locusOfFocus
         while obj:
             role = obj.getRole()
@@ -593,3 +630,48 @@ class Script(Gecko.Script):
                 obj = obj.parent
 
         return None
+
+    def toggleFlatReviewMode(self, inputEvent=None):
+        """Toggles between flat review mode and focus tracking mode."""
+
+        # If we're leaving flat review dump the cache. See bug 568658.
+        #
+        if self.flatReviewContext:
+            pyatspi.clearCache()
+
+        return default.Script.toggleFlatReviewMode(self, inputEvent)
+
+    def isNonHTMLEntry(self, obj):
+        """Checks for ROLE_ENTRY areas that are not part of an HTML
+        document.  See bug #607414.
+
+        Returns True is this is something like the Subject: entry
+        """
+        result = obj and obj.getRole() == pyatspi.ROLE_ENTRY \
+            and None == self.getAncestor(obj,
+                                         [pyatspi.ROLE_DOCUMENT_FRAME],
+                                         [pyatspi.ROLE_FRAME])
+        return result
+
+    def isEditableMessage(self, obj):
+        """Returns True if this is a editable message."""
+
+        # For now, look specifically to see if this object is the
+        # document frame. If it's not, we cannot be sure how complex
+        # this message is and should let the Gecko code kick in.
+        #
+        if obj \
+           and obj.getRole() == pyatspi.ROLE_DOCUMENT_FRAME \
+           and obj.getState().contains(pyatspi.STATE_EDITABLE):
+            return True
+
+        return False
+
+    def useCaretNavigationModel(self, keyboardEvent):
+        """Returns True if we should do our own caret navigation."""
+
+        if self.isEditableMessage(orca_state.locusOfFocus) \
+           or self.isNonHTMLEntry(orca_state.locusOfFocus):
+            return False
+
+        return Gecko.Script.useCaretNavigationModel(self, keyboardEvent)
