@@ -228,6 +228,11 @@ DESKTOP_MODIFIER_KEYS = ["Insert", "KP_Insert"]
 LAPTOP_MODIFIER_KEYS  = ["Caps_Lock"]
 orcaModifierKeys      = DESKTOP_MODIFIER_KEYS
 
+# If True, some validation of the keybindings will be done to check for
+# missing keysyms and duplicate keys used for different operations.
+#
+validateKeyBindings = False
+
 # A new modifier to use (set by the press of any key in the
 # orcaModifierKeys list) to represent the Orca modifier.
 #
@@ -899,7 +904,8 @@ doubleClickTimeout = 0.5
 #
 def isAccessibilityEnabled():
     try:
-        return gconfClient.get_bool("/desktop/gnome/interface/accessibility")
+        return gconfClient.get_bool("/desktop/gnome/interface/accessibility") \
+            or gconfClient.get_bool("/desktop/gnome/interface/accessibility2")
     except:
         return False
 
@@ -1081,6 +1087,8 @@ setScriptMapping(re.compile(_('Minefield')), "Mozilla")
 #setScriptMapping(re.compile(_('Shiretoko')), "Mozilla")
 setScriptMapping(re.compile('Shiretoko'), "Mozilla")
 
+setScriptMapping(re.compile('Namoroka'), "Mozilla")
+
 # This is a temporary fix for the schema/FF 3.0 not being accessible
 # issue. (See GNOME bugs #535827 and #555466.)
 #
@@ -1115,6 +1123,7 @@ setScriptMapping(re.compile(_('vte')), "gnome-terminal")
 # supporting gaim, which has recently be renamed to pidgin.
 #
 setScriptMapping(re.compile(_('gaim')), "pidgin")
+setScriptMapping(re.compile('Pidgin'), "pidgin")
 
 # Translators: see the regular expression note above.  This is for
 # supporting yelp, which sometimes identifies itself as gnome-help.
@@ -1126,6 +1135,14 @@ setScriptMapping(re.compile(_('gaim')), "pidgin")
 #setScriptMapping(re.compile(_('gnome-help')), "yelp")
 setScriptMapping(re.compile('gnome-help'), "yelp")
 
+# This is for development builds of Banshee
+setScriptMapping(re.compile('Nereid'), "Banshee")
+
+# Strip off the extra 'py' that the Device Driver Utility includes
+# as part of its accessible name.
+#
+setScriptMapping(re.compile('ddu.py'), "ddu")
+
 # Show deprecated messeges in debug output.
 # Set this to True to help find potential pyatspi porting problems
 #
